<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <!-- <el-form-item label="ID" prop="appId">
        <el-input
          v-model="queryParams.appId"
          placeholder="请输入ID"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item> -->
      <el-form-item label="标题" prop="title">
        <el-input
          v-model="queryParams.title"
          placeholder="请输入标题"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" class="m-2" placeholder="请选择状态" clearable
          @keyup.enter.native="handleQuery">
          <el-option v-for="option in options" :key="option.value" :label="option.label" :value="option.value" />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="Plus"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="Delete"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
            type="info"
            plain
            icon="Upload"
            @click="handleImport"
        >导入</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
            type="info"
            plain
            icon="Download"
            @click="handleExport"
        >导出</el-button>
      </el-col>
    </el-row>

    <el-table v-loading="loading" :data="appList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" align="center" prop="appId" />
      <el-table-column label="标题" align="center" prop="title" />
      <el-table-column label="价格" align="center" prop="price" >
        <template #default="scope">
          <span>{{ formatPrice(scope.row.price) }} 元</span>
        </template>
      </el-table-column>
      <el-table-column label="状态" align="center" prop="status" >
        <template #default="scope">
          <el-switch
              v-model="scope.row.status"
              :active-value="1"
              :inactive-value="0"
              @change="handleStatusChange(scope.row)"
            ></el-switch>
        </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createTime" width="180">
        <template #default="scope">
          <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="更新时间" align="center" prop="updateTime" width="180">
        <template #default="scope">
          <span>{{ parseTime(scope.row.updateTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template #default="scope">
          <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)">修改</el-button>
          <el-button link type="primary" icon="Delete" @click="handleDelete(scope.row)">删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page="queryParams.pageNum"
      :limit="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改应用对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="appRef" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="标题" prop="title">
          <el-input v-model="form.title" placeholder="请输入标题" />
        </el-form-item>
        <el-form-item label="价格" prop="price">
          <el-input v-model="form.price" placeholder="请输入价格">
          <template #prepend>¥</template>
          </el-input>
        </el-form-item>
        <el-form-item label="上传应用" prop="path">
          <el-input v-model="form.path" placeholder="请输入地址" />
        </el-form-item>
        <el-form-item label="预设展示点" prop="spots">
          <el-input v-model="form.spots" type="textarea" placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>


      <!--  导入  -->
          <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
            <el-upload
                       :limit="1"
                       accept=".xls,.xlsx"
                       ref="uploadRef"
                       :headers="upload.headers"
                       :action="upload.url + '?updateSupport=' + upload.updateSupport"
                       :disabled="upload.isUploading"
                       :on-progress="handleFileUploadProgress"
                       :on-success="handleFileSuccess"
                       :auto-upload="false"
                       drag
            >
              <el-icon class="el-icon--upload"><upload-filled /></el-icon>
              <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
              <template #tip>
                <div class="el-upload__tip text-center">
                  <div class="el-upload__tip">
                    <el-checkbox v-model="upload.updateSupport" />是否更新已经存在的用户数据
                  </div>
                  <span>仅允许导入xls、xlsx格式文件。</span>
                  <el-link type="primary" :underline="false" style="font-size:12px;vertical-align: baseline;" @click="importTemplate">下载模板</el-link>
                </div>
              </template>
            </el-upload>
            <template #footer>
              <div class="dialog-footer" style="text-align: right;">
                <el-button @click="upload.open = false">取 消</el-button>
                <el-button type="primary" @click="submitFileForm">确 定</el-button>
              </div>
            </template>
          </el-dialog>
</div>
</template>

<script setup name="App" >
import {listApp, getApp, delApp, addApp, updateApp, updateAppstatus, exportApp} from "@/api/VRdemo/app";
import {getToken} from "@/utils/auth";
import fileDownload from 'js-file-download'

const { proxy } = getCurrentInstance();

const appList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    appId: null,
    title: null,
    status: null,
  },
  
  rules: {
    title: [
      { required: true, message: "标题不能为空", trigger: "blur" }
    ],
    price: [
      { required: true, message: "价格不能为空", pattern: /^\d{1,7}(\.\d{1,2})?$/, message: "请输入正确的金额", trigger: "blur" }
    ],
    path: [
      { required: true, message: "上传应用不能为空", trigger: "blur" }
    ],
    spots: [
      { required: true, message: "预设展示点不能为空", trigger: "blur" }
    ],
  }
});


const upload = reactive({
  // 是否显示弹出层（应用导入）
  open: false,
  // 弹出层标题（应用导入）
  title: "",
  // 是否禁用上传
  isUploading: false,
  // 是否更新已经存在的用户数据
  updateSupport: 0,
  // 设置上传的请求头部
  headers: { Authorization: "Bearer " + getToken() },
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + "/excel/import/app"
});

// 查询状态选择
const options = [
  {
    value: '1',
    label: '启用',
  },
  {
    value: '0',
    label: '禁用',
  }
]

//格式化金额
const formatPrice = (value) => {
  return value.toLocaleString('en-US', { minimumFractionDigits: 2, maximumFractionDigits: 2 });
};

const { queryParams, form, rules } = toRefs(data);

/** 查询应用列表 */
function getList() {
  loading.value = true;
  listApp(queryParams.value).then(response => {
    appList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    appId: null,
    title: null,
    price: null,
    path: null,
    spots: null,
    status: null,
  };
  proxy.resetForm("appRef");
}

/** 导出按钮 */
function handleExport() {

  exportApp().then((res )=> {
    // 调用 fileDownload 下载即可
    fileDownload(res, "class.xlsx")

  })
}
/** 下载模板 */
function importTemplate() {
  proxy.download("excel/importTemplate/app", {
  }, `app_template_${new Date().getTime()}.xlsx`);
};

/** 导入按钮 */
function handleImport() {
  upload.title = "应用导入";
  upload.open = true;
};

/**导入中处理 */
const handleFileUploadProgress = (event, file, fileList) => {
  upload.isUploading = true;
};

/** 导入成功处理 */
const handleFileSuccess = (response, file, fileList) => {
  upload.open = false;
  upload.isUploading = false;
  proxy.$refs["uploadRef"].handleRemove(file);
  proxy.$alert("<div style='overflow: auto;overflow-x: hidden;max-height: 70vh;padding: 10px 20px 0;'>" + response.msg + "</div>", "导入结果", { dangerouslyUseHTMLString: true });

  getList();
};

/** 导入确认按钮 */
function submitFileForm() {
  const updateSupportValue = upload.updateSupport;
  proxy.$refs["uploadRef"].submit(updateSupportValue);
};

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.appId);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加应用";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _appId = row.appId || ids.value
  getApp(_appId).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改应用";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["appRef"].validate(valid => {
    if (valid) {
      if (form.value.appId != null) {
        updateApp(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addApp(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _appIds = row.appId || ids.value;
  proxy.$modal.confirm('是否确认删除应用编号为"' + _appIds + '"的数据项？').then(function() {
    return delApp(_appIds);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}



/** 应用状态修改 */
function handleStatusChange(row) {
  let text = row.status === 1 ? "启用" : "停用";
  proxy.$modal.confirm('确认要"' + text + '""' + row.title + '"应用吗?').then(function () {
    return updateAppstatus(row.appId, row.status);
  }).then(() => {
    proxy.$modal.msgSuccess(text + "成功");
  }).catch(function () {
    row.status = row.status === 0 ? 1 : 0;
  });
};
getList();
</script>
